public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
From: "Lars Wendler" <polynomial-c@gentoo.org>
To: gentoo-commits@lists.gentoo.org
Subject: [gentoo-commits] proj/apache:master commit in: /
Date: Sun, 20 Apr 2014 20:39:34 +0000 (UTC)	[thread overview]
Message-ID: <1398026346.6c86ae4c69a6b1baed8be02a6d1dc72d08d88e38.polynomial-c@gentoo> (raw)

commit:     6c86ae4c69a6b1baed8be02a6d1dc72d08d88e38
Author:     Lars Wendler <polynomial-c <AT> gentoo <DOT> org>
AuthorDate: Sun Apr 20 20:39:06 2014 +0000
Commit:     Lars Wendler <polynomial-c <AT> gentoo <DOT> org>
CommitDate: Sun Apr 20 20:39:06 2014 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/apache.git;a=commit;h=6c86ae4c

Change GENTOO_PATCHNAME in ebuild as well

---
 rolltarball.sh | 15 +++++++++------
 1 file changed, 9 insertions(+), 6 deletions(-)

diff --git a/rolltarball.sh b/rolltarball.sh
index d296b5b..1962c00 100755
--- a/rolltarball.sh
+++ b/rolltarball.sh
@@ -16,7 +16,8 @@
 #
 # Changes:
 #	05-Jun-2005	Complete rewrite to clean up code
 #	20-Apr-2014	Use git instead of svn
 #
 
 # Please increase version number before each commit which includes changes to
@@ -373,6 +374,7 @@ edebug "Detecting settings for tarball based on ebuild name"
 
 EBUILD_BASE=$(basename ${EBUILD})
 EBUILD_NAME=${EBUILD_BASE/-[0-9]*/}
+TB_NAME="gentoo-${EBUILD_NAME}"
 TB_VER=${EBUILD_BASE/${EBUILD_NAME}-/}
 TB_VER=${TB_VER/.ebuild/}
 DATESTAMP=${DATESTAMP:-$(date +%Y%m%d)}
@@ -380,8 +382,8 @@ DATESTAMP=${DATESTAMP:-$(date +%Y%m%d)}
 case ${EBUILD_NAME} in
 	apache)
 		TREE=${TB_VER%.*}
-		TB=gentoo-apache-${TB_VER}-${DATESTAMP}.tar.bz2
-		TB_DIR=gentoo-apache-${TB_VER}
+		TB=${TB_NAME}-${TB_VER}-${DATESTAMP}.tar.bz2
+		TB_DIR=${TB_NAME}-${TB_VER}
 		;;
 	gentoo-webroot-default)
 		TREE=gentoo-webroot-default
@@ -496,11 +498,12 @@ build_tarball() {
 	then
 		if [ -r ${EBUILD} ]
 		then
-			pretend && einfo "  Update GENTOO_PATCHSTAMP and GENTOO_DEVELOPER"
+			pretend && einfo "  Update GENTOO_PATCHSTAMP, GENTOO_DEVELOPER and GENTOO_PATCHNAME"
 			pretend || {
-				ebegin "Updating GENTOO_PATCHSTAMP and GENTOO_DEVELOPER"
+				ebegin "Updating GENTOO_PATCHSTAMP, GENTOO_DEVELOPER and GENTOO_PATCHNAME"
 				sed -i -e "s/GENTOO_PATCHSTAMP=\".*\"/GENTOO_PATCHSTAMP=\"${DATESTAMP}\"/" ${EBUILD} && 
-				sed -i -e "s/GENTOO_DEVELOPER=\".*\"/GENTOO_DEVELOPER=\"${G_USER}\"/" ${EBUILD}
+				sed -i -e "s/GENTOO_DEVELOPER=\".*\"/GENTOO_DEVELOPER=\"${G_USER}\"/" ${EBUILD} &&
+				sed -i -e "s/GENTOO_PATCHNAME=\".*\"/GENTOO_PATCHNAME=\"${TB_NAME}-${TB_VER}\"/" ${EBUILD}
 				eend $? "Failed to modify ebuild" || {
 					einfo "It's highly recommended that you delete the ebuild"
 					einfo "and cvs up and then modify the ebuild manually."
@@ -16,7 +16,8 @@
 # Changes:
 #	05-Jun-2005	Complete rewrite to clean up code
-#	20-Apr-2014	Use git instead of svn
+#	20-Apr-2014	Use git instead of svn. Change patchname in ebuild as
+#			well
 #
 


             reply	other threads:[~2014-04-20 20:39 UTC|newest]

Thread overview: 10+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2014-04-20 20:39 Lars Wendler [this message]
  -- strict thread matches above, loose matches on Subject: below --
2023-09-03  8:10 [gentoo-commits] proj/apache:master commit in: / Hans de Graaff
2021-02-12 14:55 Lars Wendler
2021-02-12 14:38 Lars Wendler
2021-02-12 14:28 Lars Wendler
2020-12-01 12:26 Lars Wendler
2020-12-01 12:19 Lars Wendler
2020-12-01 12:19 Lars Wendler
2014-04-20 20:12 Lars Wendler
2013-11-09 15:32 Lars Wendler

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1398026346.6c86ae4c69a6b1baed8be02a6d1dc72d08d88e38.polynomial-c@gentoo \
    --to=polynomial-c@gentoo.org \
    --cc=gentoo-commits@lists.gentoo.org \
    --cc=gentoo-dev@lists.gentoo.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox